Welcome to ClientVPS Mirrors

Help for package RcppMagicEnum
Type: Package
Title: 'Rcpp' Bindings to 'Magic Enum' 'C++' 'Enum' Support
Version: 0.0.1
Date: 2024-07-31
Description: The header-only modern 'C++' template library 'Magic Enum' for static reflection of 'enums' (to string, from string, iteration) is provided by this package. More information about the underlying library can be found at its repository at https://github.com/Neargye/magic_enum.
URL: https://github.com/eddelbuettel/rcppmagicenum
BugReports: https://github.com/eddelbuettel/rcppmagicenum/issues
License: MIT + file LICENSE
Imports: Rcpp (≥ 1.0.10)
LinkingTo: Rcpp
Suggests: tinytest
Encoding: UTF-8
RoxygenNote: 6.0.1
NeedsCompilation: yes
Packaged: 2024-07-31 11:48:11 UTC; edd
Author: Dirk Eddelbuettel ORCID iD [aut, cre], Daniil Goncharov [aut] (Autor of 'magic_enum')
Maintainer: Dirk Eddelbuettel <edd@debian.org>
Repository: CRAN
Date/Publication: 2024-08-19 08:30:02 UTC

'Rcpp' Bindings to 'Magic Enum' 'C++' 'Enum' Support

Description

The header-only modern 'C++' template library 'Magic Enum' for static reflection of 'enums' (to string, from string, iteration) is provided by this package. More information about the underlying library can be found at its repository at <https://github.com/Neargye/magic_enum>.

Package Content

Index of help topics:

RcppMagicEnum-package   'Rcpp' Bindings to 'Magic Enum' 'C++' 'Enum'
                        Support
magic_enum_example      Examples of 'magic_enum' use via
                        'RcppMagicEnum'

Maintainer

Dirk Eddelbuettel <edd@debian.org>

Author(s)

Dirk Eddelbuettel [aut, cre] (<https://orcid.org/0000-0001-6419-907X>), Daniil Goncharov [aut] (Autor of 'magic_enum')


Examples of ‘magic_enum’ use via RcppMagicEnum

Description

This example, directly almost verbatim from the upstream README.md shows several simple usage patterns for enumerations enabled by the package.

Usage

magic_enum_example()

Value

The function returns nothing and is invoked for its side-effect of displaying output to the console.

Examples

magic_enum_example()

Need a high-speed mirror for your open-source project?
Contact our mirror admin team at info@clientvps.com.

This archive is provided as a free public service to the community.
Proudly supported by infrastructure from VPSPulse , RxServers , BuyNumber , UnitVPS , OffshoreName and secure payment technology by ArionPay.